package othello;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.rmi.* ;

import javax.swing.JFrame;
import javax.swing.SwingUtilities;
import javax.swing.Timer;
import javax.swing.WindowConstants;

import othello.model.* ;
import othello.view.* ;
/**
 * <p>Title: Othello</p>
 * <p>Description: </p>
 * <p>Copyright: Copyright (c) 2003</p>
 * <p>Company: Memorial University</p>
 * @author Theodore Norvell
 * @version 1.0
 */

public class TestMain2 implements GameConstants {

    // This is a test of all the objects running in one
    // JVM
	public static void main(String[] args) {
		RemoteGameModel gameModel ;
		Animator animator0  ;
		Animator animator1  ;
		try { 

			gameModel = new RemoteGameModel() ;
			animator0 = new Animator( gameModel ) ;
			animator1 = new Animator( gameModel ) ; }
		catch( RemoteException e ) { 
			gameModel = null ;
			animator0 = animator1 = null ;
			System.err.println( "Remote Exception on building" );
			e.printStackTrace( System.err );
			System.exit( 1 ); }

		buildGUI(gameModel, animator0,animator1) ;
		
		try { // Wait until GUI is ready.
			Thread.sleep(1000);
		} catch (InterruptedException e) {}
		
		//Start playing
		gameModel.getColour() ;
		gameModel.getColour() ;
		gameModel.move(6, 5, BLACK) ;
		gameModel.move(6, 4, WHITE) ;
		gameModel.move(4, 3, BLACK) ;
	}

	private static void buildGUI(final RemoteGameModel gameModel,
			                              final Animator animator0,
			                              final Animator animator1) {
		SwingUtilities.invokeLater(new Runnable(){

			@Override
			public void run() {

		       
		            
		        ViewStrategy birdsEye = new BirdsEyeViewStrategy() ;
		        ViewStrategy perspective = new PerspectiveViewStrategy() ;
		        
		        BoardView view0 = new BoardView( animator0, birdsEye ) ;
		        JFrame frame0 = new JFrame() ;
		        frame0.setDefaultCloseOperation( WindowConstants.EXIT_ON_CLOSE ) ;
		        frame0.add( view0 ) ;
		        frame0.setSize(350, 350);
		        frame0.setVisible( true );
		        
		        
		        BoardView view1 = new BoardView( animator1, birdsEye ) ;
		        JFrame frame1 = new JFrame() ;
		        frame1.setDefaultCloseOperation( WindowConstants.EXIT_ON_CLOSE ) ;
		        frame1.add( view1 ) ;
		        frame1.setBounds(350, 0, 350, 350);
		        frame1.setVisible( true );
		        
		        BoardView view2 = new BoardView( animator0, perspective ) ;
		        JFrame frame2 = new JFrame() ;
		        frame2.setDefaultCloseOperation( WindowConstants.EXIT_ON_CLOSE ) ;
		        frame2.add( view2 ) ;
		        frame2.setBounds(0, 350, 350, 350);
		        frame2.setVisible( true );
		        
		        
		        BoardView view3 = new BoardView( animator1, perspective ) ;
		        JFrame frame3 = new JFrame() ;
		        frame3.setDefaultCloseOperation( WindowConstants.EXIT_ON_CLOSE ) ;
		        frame3.add( view3 ) ;
		        frame3.setBounds(350, 350, 350, 350);
		        frame3.setVisible( true ) ;
			}});
	}
        
}
