package othello.model;

import java.rmi.* ;

import othello.observation.* ;

/** Interface for the game model
 * <p>Title: Othello</p>
 * <p>Description: </p>
 * <p>Copyright: Copyright (c) 2003</p>
 * <p>Company: Memorial University</p>
 * @author Theodore S. Norvell
 * @version 1.0
 */

public interface RemoteGameModelInterface extends GameConstants, Remote {
    public static final int BLACK_TO_MOVE = 1 ;
    public static final int WHITE_TO_MOVE = 2 ;
    public static final int TIE_GAME = 4 ;
    public static final int BLACK_HAS_WON = 8 ;
    public static final int WHITE_HAS_WON = 16 ;
    public static final int UNINITIALIZED = 32 ;
    
    public static final int DONE = 1 ;
    public static final int NOT_YOUR_TURN = 2 ;
    public static final int ILLEGAL_MOVE = 4 ;
    
    
    /** Get colour for player the board state.
        Two clients can call this routine. When the
        second client calls this routine the game
        is initialized.
     */
    public int getColour() throws RemoteException;
    
       
    /** Report the state of the game.
     *  @returns one of the states BLACK_TO_MOVE, WHITE_TO_MOVE, TIE_GAME,
     *   BLACK_HAS_WON, WHITE_HAS_WON, UNINITIALIZED
     */
    public int getGameState()  throws RemoteException;
    
    /** Make a move. 
     *  @returns one of.
     *   DONE, NOT_YOUR_TURN, ILLEGAL_MOVE
     *   */
    public int move(int row, int col, int colour ) throws RemoteException ;
    
    /** Add a java.util.Observer.
     *  Observers will be notified after each mutator call
     */
    void addObserver( RemoteConcurrentObserver o)  throws RemoteException ;
    
    
    /** Report the colour of a piece.
     *  Result will be in { BLACK, EMPTY, WHITE }
     */
    int getPieceAt( int row, int col ) throws RemoteException;
}
